==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkWindowedSincPolyDataFilter.java <==
// java wrapper for vtkWindowedSincPolyDataFilter object
//

package vtk;
import vtk.*;

public class vtkWindowedSincPolyDataFilter extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfIterations_2(int id0);
  public void SetNumberOfIterations(int id0)
    { SetNumberOfIterations_2(id0); }

  private native int GetNumberOfIterationsMinValue_3();
  public int GetNumberOfIterationsMinValue()
    { return GetNumberOfIterationsMinValue_3(); }

  private native int GetNumberOfIterationsMaxValue_4();
  public int GetNumberOfIterationsMaxValue()
    { return GetNumberOfIterationsMaxValue_4(); }

  private native int GetNumberOfIterations_5();
  public int GetNumberOfIterations()
    { return GetNumberOfIterations_5(); }

  private native void SetPassBand_6(double id0);
  public void SetPassBand(double id0)
    { SetPassBand_6(id0); }

  private native double GetPassBandMinValue_7();
  public double GetPassBandMinValue()
    { return GetPassBandMinValue_7(); }

  private native double GetPassBandMaxValue_8();
  public double GetPassBandMaxValue()
    { return GetPassBandMaxValue_8(); }

  private native double GetPassBand_9();
  public double GetPassBand()
    { return GetPassBand_9(); }

  private native void SetNormalizeCoordinates_10(int id0);
  public void SetNormalizeCoordinates(int id0)
    { SetNormalizeCoordinates_10(id0); }

  private native int GetNormalizeCoordinates_11();
  public int GetNormalizeCoordinates()
    { return GetNormalizeCoordinates_11(); }

  private native void NormalizeCoordinatesOn_12();
  public void NormalizeCoordinatesOn()
    { NormalizeCoordinatesOn_12(); }

  private native void NormalizeCoordinatesOff_13();
  public void NormalizeCoordinatesOff()
    { NormalizeCoordinatesOff_13(); }

  private native void SetFeatureEdgeSmoothing_14(int id0);
  public void SetFeatureEdgeSmoothing(int id0)
    { SetFeatureEdgeSmoothing_14(id0); }

  private native int GetFeatureEdgeSmoothing_15();
  public int GetFeatureEdgeSmoothing()
    { return GetFeatureEdgeSmoothing_15(); }

  private native void FeatureEdgeSmoothingOn_16();
  public void FeatureEdgeSmoothingOn()
    { FeatureEdgeSmoothingOn_16(); }

  private native void FeatureEdgeSmoothingOff_17();
  public void FeatureEdgeSmoothingOff()
    { FeatureEdgeSmoothingOff_17(); }

  private native void SetFeatureAngle_18(double id0);
  public void SetFeatureAngle(double id0)
    { SetFeatureAngle_18(id0); }

  private native double GetFeatureAngleMinValue_19();
  public double GetFeatureAngleMinValue()
    { return GetFeatureAngleMinValue_19(); }

  private native double GetFeatureAngleMaxValue_20();
  public double GetFeatureAngleMaxValue()
    { return GetFeatureAngleMaxValue_20(); }

  private native double GetFeatureAngle_21();
  public double GetFeatureAngle()
    { return GetFeatureAngle_21(); }

  private native void SetEdgeAngle_22(double id0);
  public void SetEdgeAngle(double id0)
    { SetEdgeAngle_22(id0); }

  private native double GetEdgeAngleMinValue_23();
  public double GetEdgeAngleMinValue()
    { return GetEdgeAngleMinValue_23(); }

  private native double GetEdgeAngleMaxValue_24();
  public double GetEdgeAngleMaxValue()
    { return GetEdgeAngleMaxValue_24(); }

  private native double GetEdgeAngle_25();
  public double GetEdgeAngle()
    { return GetEdgeAngle_25(); }

  private native void SetBoundarySmoothing_26(int id0);
  public void SetBoundarySmoothing(int id0)
    { SetBoundarySmoothing_26(id0); }

  private native int GetBoundarySmoothing_27();
  public int GetBoundarySmoothing()
    { return GetBoundarySmoothing_27(); }

  private native void BoundarySmoothingOn_28();
  public void BoundarySmoothingOn()
    { BoundarySmoothingOn_28(); }

  private native void BoundarySmoothingOff_29();
  public void BoundarySmoothingOff()
    { BoundarySmoothingOff_29(); }

  private native void SetNonManifoldSmoothing_30(int id0);
  public void SetNonManifoldSmoothing(int id0)
    { SetNonManifoldSmoothing_30(id0); }

  private native int GetNonManifoldSmoothing_31();
  public int GetNonManifoldSmoothing()
    { return GetNonManifoldSmoothing_31(); }

  private native void NonManifoldSmoothingOn_32();
  public void NonManifoldSmoothingOn()
    { NonManifoldSmoothingOn_32(); }

  private native void NonManifoldSmoothingOff_33();
  public void NonManifoldSmoothingOff()
    { NonManifoldSmoothingOff_33(); }

  private native void SetGenerateErrorScalars_34(int id0);
  public void SetGenerateErrorScalars(int id0)
    { SetGenerateErrorScalars_34(id0); }

  private native int GetGenerateErrorScalars_35();
  public int GetGenerateErrorScalars()
    { return GetGenerateErrorScalars_35(); }

  private native void GenerateErrorScalarsOn_36();
  public void GenerateErrorScalarsOn()
    { GenerateErrorScalarsOn_36(); }

  private native void GenerateErrorScalarsOff_37();
  public void GenerateErrorScalarsOff()
    { GenerateErrorScalarsOff_37(); }

  private native void SetGenerateErrorVectors_38(int id0);
  public void SetGenerateErrorVectors(int id0)
    { SetGenerateErrorVectors_38(id0); }

  private native int GetGenerateErrorVectors_39();
  public int GetGenerateErrorVectors()
    { return GetGenerateErrorVectors_39(); }

  private native void GenerateErrorVectorsOn_40();
  public void GenerateErrorVectorsOn()
    { GenerateErrorVectorsOn_40(); }

  private native void GenerateErrorVectorsOff_41();
  public void GenerateErrorVectorsOff()
    { GenerateErrorVectorsOff_41(); }

  public vtkWindowedSincPolyDataFilter() { super(); }

  public vtkWindowedSincPolyDataFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkWindowedSincPolyDataFilter.java <==
// java wrapper for vtkWindowedSincPolyDataFilter object
//

package vtk;
import vtk.*;

public class vtkWindowedSincPolyDataFilter extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetNumberOfIterations_2(int id0);
  public void SetNumberOfIterations(int id0)
    { SetNumberOfIterations_2(id0); }

  private native int GetNumberOfIterationsMinValue_3();
  public int GetNumberOfIterationsMinValue()
    { return GetNumberOfIterationsMinValue_3(); }

  private native int GetNumberOfIterationsMaxValue_4();
  public int GetNumberOfIterationsMaxValue()
    { return GetNumberOfIterationsMaxValue_4(); }

  private native int GetNumberOfIterations_5();
  public int GetNumberOfIterations()
    { return GetNumberOfIterations_5(); }

  private native void SetPassBand_6(double id0);
  public void SetPassBand(double id0)
    { SetPassBand_6(id0); }

  private native double GetPassBandMinValue_7();
  public double GetPassBandMinValue()
    { return GetPassBandMinValue_7(); }

  private native double GetPassBandMaxValue_8();
  public double GetPassBandMaxValue()
    { return GetPassBandMaxValue_8(); }

  private native double GetPassBand_9();
  public double GetPassBand()
    { return GetPassBand_9(); }

  private native void SetNormalizeCoordinates_10(int id0);
  public void SetNormalizeCoordinates(int id0)
    { SetNormalizeCoordinates_10(id0); }

  private native int GetNormalizeCoordinates_11();
  public int GetNormalizeCoordinates()
    { return GetNormalizeCoordinates_11(); }

  private native void NormalizeCoordinatesOn_12();
  public void NormalizeCoordinatesOn()
    { NormalizeCoordinatesOn_12(); }

  private native void NormalizeCoordinatesOff_13();
  public void NormalizeCoordinatesOff()
    { NormalizeCoordinatesOff_13(); }

  private native void SetFeatureEdgeSmoothing_14(int id0);
  public void SetFeatureEdgeSmoothing(int id0)
    { SetFeatureEdgeSmoothing_14(id0); }

  private native int GetFeatureEdgeSmoothing_15();
  public int GetFeatureEdgeSmoothing()
    { return GetFeatureEdgeSmoothing_15(); }

  private native void FeatureEdgeSmoothingOn_16();
  public void FeatureEdgeSmoothingOn()
    { FeatureEdgeSmoothingOn_16(); }

  private native void FeatureEdgeSmoothingOff_17();
  public void FeatureEdgeSmoothingOff()
    { FeatureEdgeSmoothingOff_17(); }

  private native void SetFeatureAngle_18(double id0);
  public void SetFeatureAngle(double id0)
    { SetFeatureAngle_18(id0); }

  private native double GetFeatureAngleMinValue_19();
  public double GetFeatureAngleMinValue()
    { return GetFeatureAngleMinValue_19(); }

  private native double GetFeatureAngleMaxValue_20();
  public double GetFeatureAngleMaxValue()
    { return GetFeatureAngleMaxValue_20(); }

  private native double GetFeatureAngle_21();
  public double GetFeatureAngle()
    { return GetFeatureAngle_21(); }

  private native void SetEdgeAngle_22(double id0);
  public void SetEdgeAngle(double id0)
    { SetEdgeAngle_22(id0); }

  private native double GetEdgeAngleMinValue_23();
  public double GetEdgeAngleMinValue()
    { return GetEdgeAngleMinValue_23(); }

  private native double GetEdgeAngleMaxValue_24();
  public double GetEdgeAngleMaxValue()
    { return GetEdgeAngleMaxValue_24(); }

  private native double GetEdgeAngle_25();
  public double GetEdgeAngle()
    { return GetEdgeAngle_25(); }

  private native void SetBoundarySmoothing_26(int id0);
  public void SetBoundarySmoothing(int id0)
    { SetBoundarySmoothing_26(id0); }

  private native int GetBoundarySmoothing_27();
  public int GetBoundarySmoothing()
    { return GetBoundarySmoothing_27(); }

  private native void BoundarySmoothingOn_28();
  public void BoundarySmoothingOn()
    { BoundarySmoothingOn_28(); }

  private native void BoundarySmoothingOff_29();
  public void BoundarySmoothingOff()
    { BoundarySmoothingOff_29(); }

  private native void SetNonManifoldSmoothing_30(int id0);
  public void SetNonManifoldSmoothing(int id0)
    { SetNonManifoldSmoothing_30(id0); }

  private native int GetNonManifoldSmoothing_31();
  public int GetNonManifoldSmoothing()
    { return GetNonManifoldSmoothing_31(); }

  private native void NonManifoldSmoothingOn_32();
  public void NonManifoldSmoothingOn()
    { NonManifoldSmoothingOn_32(); }

  private native void NonManifoldSmoothingOff_33();
  public void NonManifoldSmoothingOff()
    { NonManifoldSmoothingOff_33(); }

  private native void SetGenerateErrorScalars_34(int id0);
  public void SetGenerateErrorScalars(int id0)
    { SetGenerateErrorScalars_34(id0); }

  private native int GetGenerateErrorScalars_35();
  public int GetGenerateErrorScalars()
    { return GetGenerateErrorScalars_35(); }

  private native void GenerateErrorScalarsOn_36();
  public void GenerateErrorScalarsOn()
    { GenerateErrorScalarsOn_36(); }

  private native void GenerateErrorScalarsOff_37();
  public void GenerateErrorScalarsOff()
    { GenerateErrorScalarsOff_37(); }

  private native void SetGenerateErrorVectors_38(int id0);
  public void SetGenerateErrorVectors(int id0)
    { SetGenerateErrorVectors_38(id0); }

  private native int GetGenerateErrorVectors_39();
  public int GetGenerateErrorVectors()
    { return GetGenerateErrorVectors_39(); }

  private native void GenerateErrorVectorsOn_40();
  public void GenerateErrorVectorsOn()
    { GenerateErrorVectorsOn_40(); }

  private native void GenerateErrorVectorsOff_41();
  public void GenerateErrorVectorsOff()
    { GenerateErrorVectorsOff_41(); }

  public vtkWindowedSincPolyDataFilter() { super(); }

  public vtkWindowedSincPolyDataFilter(long id) { super(id); }
  public native long   VTKInit();

}
